#
# spec file for package tokodon
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without released
Name:           tokodon
Version:        23.08.2
Release:        1.1
Summary:        Mastodon client by KDE
License:        GPL-3.0-only
URL:            https://apps.kde.org/tokodon/
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  breeze5-icons
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Kirigami2)
BuildRequires:  cmake(KF5KirigamiAddons) >= 0.11
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5QQC2DesktopStyle)
BuildRequires:  cmake(KF5WindowSystem) >= 5.91
BuildRequires:  cmake(Qt5Core) >= 5.15.2
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Keychain)
BuildRequires:  cmake(Qt5Multimedia)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5WebSockets)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(mpv)
Requires:       kirigami2
Requires:       kirigami-addons
Requires:       kitemmodels-imports
Requires:       libqt5-qtgraphicaleffects
Requires:       libqt5-qtquickcontrols
Requires:       libqt5-qtquickcontrols2
Requires:       sonnet-imports

%description
Tokodon is a Mastodon client. It allows you to interact with the Fediverse
community.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build

%cmake_build

%install
%kf5_makeinstall -C build

%find_lang tokodon tokodon.lang

%files
%license LICENSES/*
%doc README.md
%{_kf5_applicationsdir}/org.kde.tokodon.desktop
%{_kf5_appstreamdir}/org.kde.tokodon.appdata.xml
%{_kf5_bindir}/tokodon
%{_kf5_debugdir}/tokodon.categories
%{_kf5_iconsdir}/hicolor/scalable/apps/org.kde.tokodon.svg
%{_kf5_notifydir}/tokodon.notifyrc

%files lang -f tokodon.lang

%changelog
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * Protect against notifications that don't have a post associated (kde#475057)
  * Require kirigami-addons 0.11
  * Fix the follows page in notifications not working at all
  * Use the TextArea's implicitHeight when calculating composer height (kde#471519)
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Add release note for the past two versions
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Add fake identity so the timeline test works again
  * Use upload icons instead of download icons in the profile editor
  * You did implement account editing, uncomment the arrow
  * Use display name instead of the username in the timeline name
  * Stop Qt Quick from complaining because "there's no place to replace"
  * Improve Poll, by removing the invalid state and registering it properly
  * Stop UserInfo from reading the pageStack if nothing has been added to it
  * Fix AbstractAccount::apiUrl to strip slashes
  * Stop interactions with posts causing the entire delegate to reload
  * Improve default language selection when the preference is missing
  * Add support for more poll options, if Pleroma/Akkoma reports it
  * Handle Pleroma/Akkoma storing max post characters differently
  * Fix my dumb mistake of adding two of the same property
  * Set a maximum line count so link descriptions elide properly
  * Fix the instance name sometimes getting out of sync in switcher
  * Overhaul status composer attachment grid to match expected behavior
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * Fix spacing in LinkPreview
  * Show Link Preview only when Post Content is visible.
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes since 23.04.3, only listing bugfixes:
  * Open account links inside Tokodon (kde#472496)
  * Respect the filter action, so users can completely hide filtered posts (kde#471211)
  * Set the custom icon theme to the main icon theme, not the fallback (kde#467143)
  * Squash yet another duplicate accounts bug (kde#466440)
  * Better communique state of search progress (kde#467206)
  * Add a loading placeholder for searching (kde#467206)
  * When user hides media, automatically pause the video (kde#467214)
  * Fix -v arg not working when tokodon is already running (kde#467205)
  * Allow submitting posts by pressing CTRL+ENTER or CTRL+RETURN (kde#467164)
  * Make the composer text automatically focused (kde#467162)
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Fix obvious copy/paste mistakes
  * When going to separate app pages, clear the whole pageStack
  * Squash yet another duplicate accounts bug (kde#466440)
  * Fix reading invalid accounts from conf
* Wed May 24 2023 Christophe Marin <christophe@krop.fr>
- Require kirigami-addons
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * fix full screen image preview on NotificationPage
  * fix new post action on NotificationPage
  * Fix visible binding loop on TimelinePage
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Sat Mar 18 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Fri Feb 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.02.0:
  * https://carlschwan.eu/2023/02/17/tokodon-23.02.0-release/
  * Post composer revamp
  * The models for timelines has been completely refactored
  * The search field introduced during the last released got a
    nice visual refresh
  * It is now possible to configure the color scheme used by
    Tokodon independently from the Plasma color scheme
* Mon Jan  2 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.01.0
  * New timeline design
  * Searching post, accounts, tags is now possible
  * Hashtag Handling
  * Conversation View
  * Poll Support
  * Account Editor
  * Real-Time Timeline Update
* Tue Dec 20 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.11.2
  * New account switcher
  * Image previews are now contained inside the window
  * Improvements in loading media
  * Support for custom emojis
* Fri Nov 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Init tokodon
